pub struct OwnerRecoveryPublication {
pub commit: ExactProtocolObject<VerifiedStoreBatchCommit>,
pub head: ExactProtocolObject<StoreDeviceHead>,
pub history_evidence: RetainedMergeCommitEvidence,
}Expand description
The exact Owner-recovery commit and announcement staged before either is published. A retry reopens these same stored bytes instead of resealing the semantic objects into different exact identities.
Fields
commit: ExactProtocolObject<VerifiedStoreBatchCommit>head: ExactProtocolObject<StoreDeviceHead>history_evidence: RetainedMergeCommitEvidenceAuto Trait Implementations
impl !Freeze for OwnerRecoveryPublication
impl RefUnwindSafe for OwnerRecoveryPublication
impl Send for OwnerRecoveryPublication
impl Sync for OwnerRecoveryPublication
impl Unpin for OwnerRecoveryPublication
impl UnsafeUnpin for OwnerRecoveryPublication
impl UnwindSafe for OwnerRecoveryPublication