pub struct StagedCircleInstall {
pub activation_commit: StoreBatchCommitRef,
pub image: VerifiedCircleImage,
}Expand description
One Circle image selected against the restoring identity’s re-resolved access. Coverage references imported from the Store snapshot are removed as a set before these locally verified images are installed.
Fields
activation_commit: StoreBatchCommitRefimage: VerifiedCircleImageAuto Trait Implementations
impl Freeze for StagedCircleInstall
impl RefUnwindSafe for StagedCircleInstall
impl Send for StagedCircleInstall
impl Sync for StagedCircleInstall
impl Unpin for StagedCircleInstall
impl UnsafeUnpin for StagedCircleInstall
impl UnwindSafe for StagedCircleInstall