pub struct StagedCircleRestore {
pub access: Vec<StagedCircleAccess>,
pub bases: Vec<StagedCircleBase>,
pub packages: Option<StagedCirclePackageRestore>,
}Fields
access: Vec<StagedCircleAccess>bases: Vec<StagedCircleBase>packages: Option<StagedCirclePackageRestore>Implementations
Sourceimpl StagedCircleRestore
impl StagedCircleRestore
Sourcepub fn coverage_cuts(
&self,
) -> Result<BTreeMap<CircleId, CommitFrontier>, DbError>
pub fn coverage_cuts( &self, ) -> Result<BTreeMap<CircleId, CommitFrontier>, DbError>
Package replay starts at the selected image, or at the authenticated founding control when the recipient held active access from creation.