open_test_db_schema

Function open_test_db_schema 

pub fn open_test_db_schema(
    store_dir: StoreDir,
    tables: Vec<SyncedTable>,
    migrations: Vec<Migration>,
) -> Database
Like open_test_db but with an explicit synced set and migration ladder, for tests that exercise a different schema (gate tests).